Update your application's privacy policy to explicitly state that current precise location data is collected. Clearly describe the purposes for this collection, how the data is used, processed, stored, and its retention period. Ensure that clear user consent is obtained before accessing precise location, and provide users with easy-to-understand controls to manage this permission.